@@ -12,6 +12,7 @@
 #include "job_p.h"
 #include "response_p.h"
 #include "session_p.h"
+#include "imapset.h"
 
 namespace KIMAP
 {
@@ -19,10 +20,11 @@ class ExpungeJobPrivate : public JobPrivate
 {
 public:
     ExpungeJobPrivate(Session *session, const QString &name) : JobPrivate(session, name) { }
-    ~ExpungeJobPrivate() { }
 #if 0
     QList< int > items;
 #endif
+    KIMAP::ImapSet vanished;
+    quint64 highestModSeq = 0;
 };
 }
 
@@ -33,8 +35,16 @@ ExpungeJob::ExpungeJob(Session *session)
 {
 }
 
-ExpungeJob::~ExpungeJob()
+KIMAP::ImapSet ExpungeJob::vanishedMessages() const
 {
+    Q_D(const ExpungeJob);
+    return d->vanished;
+}
+
+quint64 ExpungeJob::newHighestModSeq() const
+{
+    Q_D(const ExpungeJob);
+    return d->highestModSeq;
 }
 
 void ExpungeJob::doStart()
@@ -45,12 +55,22 @@ void ExpungeJob::doStart()
 
 void ExpungeJob::handleResponse(const Response &response)
 {
-//  Q_D(ExpungeJob);
+    Q_D(ExpungeJob);
+
+    // Must be handler before handleErrorReplies(), so the value is available
+    // before the result is emitted.
+    if (response.responseCode.size() >= 2) {
+        if (response.responseCode[0].toString() == "HIGHESTMODSEQ") {
+            d->highestModSeq = response.responseCode[1].toString().toULongLong();
+        }
+    }
 
     if (handleErrorReplies(response) == NotHandled) {
         if (response.content.size() >= 3) {
-            QByteArray code = response.content[2].toString();
-            if (code == "EXPUNGE") {
+            if (response.content[1].toString() == "VANISHED") {
+                d->vanished = KIMAP::ImapSet::fromImapSequenceSet(response.content[2].toString());
+                return;
+            } else if (response.content[2].toString() == "EXPUNGE") {
 #if 0
                 QByteArray s = response.content[1].toString();
                 bool ok = true;
@@ -64,6 +84,5 @@ void ExpungeJob::handleResponse(const Response &response)
             }
         }
         qCDebug(KIMAP_LOG) << "Unhandled response: " << response.toString().constData();
-
     }
 }
