@@ -23,8 +23,6 @@ public:
     FetchJobPrivate(FetchJob *job, Session *session, const QString &name)
         : JobPrivate(session, name)
         , q(job)
-        , uidBased(false)
-        , gmailEnabled(false)
     { }
 
     ~FetchJobPrivate()
@@ -80,10 +78,10 @@ public:
     FetchJob *const q;
 
     ImapSet set;
-    bool uidBased;
+    bool uidBased = false;
     FetchJob::FetchScope scope;
     QString selectedMailBox;
-    bool gmailEnabled;
+    bool gmailEnabled = false;
 
     QTimer emitPendingsTimer;
     QMap<qint64, MessagePtr> pendingMessages;
@@ -98,12 +96,11 @@ public:
 
 using namespace KIMAP;
 
-FetchJob::FetchScope::FetchScope():
-    mode(FetchScope::Content),
-    changedSince(0)
-{
-
-}
+FetchJob::FetchScope::FetchScope()
+    : mode(FetchScope::Content)
+    , changedSince(0)
+    , qresync(false)
+{}
 
 FetchJob::FetchJob(Session *session)
     : Job(*new FetchJobPrivate(this, session, i18n("Fetch")))
@@ -113,10 +110,6 @@ FetchJob::FetchJob(Session *session)
             this, SLOT(emitPendings()));
 }
 
-FetchJob::~FetchJob()
-{
-}
-
 void FetchJob::setSequenceSet(const ImapSet &set)
 {
     Q_D(FetchJob);
@@ -234,7 +227,11 @@ void FetchJob::doStart()
     parameters += ")";
 
     if (d->scope.changedSince > 0) {
-        parameters += " (CHANGEDSINCE " + QByteArray::number(d->scope.changedSince) + ")";
+        parameters += " (CHANGEDSINCE " + QByteArray::number(d->scope.changedSince);
+        if (d->scope.qresync) {
+            parameters += " VANISHED";
+        }
+        parameters += ")";
     }
 
     QByteArray command = "FETCH";
@@ -262,11 +259,15 @@ void FetchJob::handleResponse(const Response &response)
 
     if (handleErrorReplies(response) == NotHandled) {
         if (response.content.size() == 4 &&
+                response.content[1].toString() == "VANISHED") {
+            const auto vanishedSet = ImapSet::fromImapSequenceSet(response.content[3].toString());
+            Q_EMIT messagesVanished(vanishedSet);
+        } else if (response.content.size() == 4 &&
                 response.content[2].toString() == "FETCH" &&
                 response.content[3].type() == Response::Part::List) {
 
-            qint64 id = response.content[1].toString().toLongLong();
-            QList<QByteArray> content = response.content[3].toList();
+            const qint64 id = response.content[1].toString().toLongLong();
+            const QList<QByteArray> content = response.content[3].toList();
 
             Message msg;
             MessagePtr message(new KMime::Message);
@@ -397,7 +398,7 @@ void FetchJobPrivate::parseBodyStructure(const QByteArray &structure, int &pos,
     } else { // multi part
         content->contentType()->setMimeType("MULTIPART/MIXED");
         while (pos < structure.size() && structure[pos] == '(') {
-            KMime::Content *child = new KMime::Content;
+            auto *child = new KMime::Content;
             content->addContent(child);
             parseBodyStructure(structure, pos, child);
             child->assemble();
